@@ -17,6 +17,7 @@ from pydmt.features.yaml import FeatureYaml
 from pydmt.features.apt import FeatureApt
 from pydmt.features.npm import FeatureNpm
 from pydmt.features.venv import FeatureVenv
+from pydmt.features.reqs import FeatureReqs
 
 
 def add_all_features(p):
@@ -96,6 +97,27 @@ def build_venv():
     sys.exit(stats.get_os_error_code())
 
 
+@register_endpoint(
+    description="Install python prerequisites",
+    configs=[
+        ConfigSudo,
+        ConfigFlow,
+        ConfigOutput,
+    ],
+)
+def build_reqs():
+    add_to_path()
+
+    pylogconf.core.setup()
+    p = PyDMT()
+
+    f = FeatureReqs()
+    f.setup(p)
+
+    stats = p.build_all()
+    sys.exit(stats.get_os_error_code())
+
+
 @register_endpoint(
     description="Build tools",
     configs=[
@@ -110,8 +132,6 @@ def build_tools():
     pylogconf.core.setup()
     p = PyDMT()
 
-    f = FeatureVenv()
-    f.setup(p)
     f = FeatureApt()
     f.setup(p)
     f = FeatureNpm()
